@@ -1,6 +1,10 @@
-#define USE_RINTERNALS 1 // needed because SET_REFCNT use in MY_named
-#include <Rinternals.h>  // needed because SET_REFCNT use in MY_named
 #include "lfe.h"
+
+#define USE_FC_LEN_T
+#ifndef FCONE
+# define FCONE
+#endif
+
 SEXP MY_scalecols(SEXP mat, SEXP vec) {
   if(!isMatrix(mat)) error("first argument should be a matrix");
   mybigint_t col = ncols(mat), row = nrows(mat);
@@ -121,8 +125,8 @@ SEXP MY_sandwich(SEXP inalpha, SEXP inbread, SEXP inmeat) {
   double zero = 0.0;
   double one = 1.0;
 
-  F77_CALL(dsymm)("R","U",&N,&N,&one,bread,&N,meat,&N,&zero,tmp,&N);
-  F77_CALL(dsymm)("L","U",&N,&N,&alpha,bread,&N,tmp,&N,&zero,out,&N);
+  F77_CALL(dsymm)("R","U",&N,&N,&one,bread,&N,meat,&N,&zero,tmp,&N FCONE FCONE);
+  F77_CALL(dsymm)("L","U",&N,&N,&alpha,bread,&N,tmp,&N,&zero,out,&N FCONE FCONE);
 
   UNPROTECT(1);
   return ret;
@@ -146,7 +150,7 @@ SEXP MY_dsyrk(SEXP inbeta, SEXP inC, SEXP inalpha, SEXP inA) {
   }
   int K = nrows(inA);
   double *A = REAL(inA);
-  F77_CALL(dsyrk)("U","T",&N, &K, &alpha, A, &K, &beta, C, &N);
+  F77_CALL(dsyrk)("U","T",&N, &K, &alpha, A, &K, &beta, C, &N FCONE FCONE);
   // fill in the lower triangular part
   for(mybigint_t row=0; row < N; row++) {
     for(mybigint_t col=0; col < row; col++) {
@@ -169,21 +173,13 @@ SEXP MY_named(SEXP x, SEXP n) {
     // return NAMED status
     SEXP res = allocVector(INTSXP, 1);
     PROTECT(res);
-#if defined(COMPUTE_REFCNT_VALUES)
-    INTEGER(res)[0] = REFCNT(x);
-#else
     INTEGER(res)[0] = NAMED(x);
-#endif
     setAttrib(res,install("x"),x);
     UNPROTECT(1);
     return(res);
   }
   // set named status. Use this at your own peril. Seriously. Things may ...
-#if defined(COMPUTE_REFCNT_VALUES)
-  SET_REFCNT(x,INTEGER(n)[0]);
-#else
   SET_NAMED(x,INTEGER(n)[0]);
-#endif
   return(x);
 }
 
